#!/usr/bin/env python
#
# Copyright 2001 by Object Craft P/L, Melbourne, Australia.
#
# LICENCE - see LICENCE file distributed with this software for details.
#
# To use:
#       python setup.py install
#
import string
import re
import os
import sys
import distutils
from distutils.core import setup, Extension
from distutils.command.sdist import sdist

if os.name == 'posix':
    mssql = '/usr'
    mssql_libs = [ 'sybdb' ]
elif os.name == 'nt':
    mssql = 'd:/mssql/dblib'
    mssql_libs = [ 'ntwdblib' ]
else:
    import sys
    sys.stderr.write(
        'Sorry, I do not know how to build on this platform.\n'
        '\n'
        'Please edit setup.py and add platform specific settings.  If you\n'
        'figure out how to get it working for your platform, please send\n'
        'mail to djc@object-craft.com.au so you can help other people.\n')
    sys.exit(1)

mssql_incdir = os.path.join(mssql, 'include')
mssql_libdir = os.path.join(mssql, 'lib')

def api_exists(func, filename):
    try:
        text = open(filename).read()
    except:
        return 0
    if re.search(func, text):
        return 1

mssql_macros = []
if api_exists('TDS_CHAR', os.path.join(mssql_incdir, 'sybdb.h')):
        mssql_macros.append(('HAVE_FREETDS', None))

for api in ('dbaltbind', 'dbclropt', 'dbcolbrowse', 'dbcurcmd',
            'DBCURROW', 'dbisopt', 'dbnumcompute', 'dbrettype',):
    if api_exists(api, os.path.join(mssql_incdir, 'sybdb.h')):
        mssql_macros.append(('HAVE_' + string.upper(api), None))

class PreReleaseCheck:
    def __init__(self, distribution):
        self.distribution = distribution
        self.check_rev('MSSQL.py', r'__version__ = \'(.*)\'')
        self.check_rev('mssqldb.c', r'rev = PyString_FromString\("(.*)"\)')

    def _extract_rev(self, filename, pattern):
        regexp = re.compile(pattern)
        match = None
        revs = []
        line_num = 0
        f = open(filename)
        try:
            for line in f.readlines():
                line_num += 1
                match = regexp.search(line)
                if match:
                    revs.append((line_num, match.group(1)))
        finally:
            f.close()
        return revs

    def check_rev(self, filename, pattern):
        file_revs = self._extract_rev(filename, pattern)
        if not file_revs:
            sys.exit("Could not locate version in %s" % filename)
        line_num, file_rev = file_revs[0]
        for num, rev in file_revs[1:]:
            if rev != file_rev:
                sys.exit("%s:%d inconsistent version on line %d" % \
                         (filename, line_num, num))
        setup_rev = self.distribution.get_version()
        if file_rev != setup_rev:
            sys.exit("%s:%d version %s does not match setup.py version %s" % \
                     (filename, line_num, file_rev, setup_rev))


class my_sdist(sdist):
    def run(self):
        PreReleaseCheck(self.distribution)
        self.announce("Pre-release checks pass!")
        sdist.run(self)

setup(name = "MSSQL",
      version = "0.07",
      maintainer = "Dave Cole",
      maintainer_email = " djc@object-craft.com.au",
      description = "MS SQL Server Extension to Python",
      url = "http://www.object-craft.com.au/projects/mssql/",
      py_modules = ['MSSQL'],
      include_dirs = [mssql_incdir],
      ext_modules = [
           Extension('mssqldb',
                     ['mssqldb.c', 'loginrec.c', 'dbproc.c', 'databuf.c',
                      'numeric.c', 'datetime.c', 'money.c'],
                     define_macros = mssql_macros,
                     libraries = mssql_libs,
                     library_dirs = [mssql_libdir]
                     )
           ],
      cmdclass={'sdist': my_sdist},
      )

